@@ -128,14 +128,14 @@ function(a){return this.getBondTo(a).isHydrogen()},"JU.Node");n(c$,"getCrossLink
 n(c$,"getResno",function(){return this.residueNumber});n(c$,"getChainID",function(){return 0});n(c$,"getChainIDStr",function(){return""});c$.getAtomLabel=j(c$,"getAtomLabel",function(a,b,c,d,e,f,g,h){var l=JU.Elements.elementSymbolFromNumber(a);g&&(l=l.toLowerCase(),6!=a&&(c=2147483647));return(2147483647==c||0!=b||0!=d||!Float.isNaN(e)||null!=h&&0<h.length?-1:JS.SmilesAtom.getDefaultCount(a,!1))==c?l:"["+(0>=b?"":""+b)+l+(null==h?"":h)+(1<f?"H"+f:1==f?"H":"")+(0>d&&-2147483648!=d?""+d:0<d?"+"+d:
 "")+(Float.isNaN(e)?"":":"+Q(e))+"]"},"~N,~N,~N,~N,~N,~N,~B,~S");n(c$,"getBioSmilesType",function(){return this.bioType});j(c$,"isNucleic",function(){return"n"==this.bioType||"r"==this.bioType||"d"==this.bioType});n(c$,"isPurine",function(){return null!=this.residueChar&&this.isNucleic()&&0<="AG".indexOf(this.residueChar)});n(c$,"isPyrimidine",function(){return null!=this.residueChar&&this.isNucleic()&&0<="CTUI".indexOf(this.residueChar)});n(c$,"isDeleted",function(){return!1});n(c$,"findAtomsLike",
 function(){return null},"~S");n(c$,"toString",function(){var a=null!=this.residueChar||null!=this.residueName?(null==this.residueChar?this.residueName:this.residueChar)+"."+this.bioAtomName:null!=this.bioAtomName&&-2147483648!=this.atomNumber?null:-1==this.elementNumber?"A":-2==this.elementNumber?"*":JU.Elements.elementSymbolFromNumber(this.elementNumber);if(null==a)return this.bioAtomName+" #"+this.atomNumber;this.isAromatic&&(a=a.toLowerCase());for(var b="",c=0;c<this.bondCount;c++)b+=this.bonds[c].getOtherAtom(this).index+
-", ";return"["+a+"."+this.index+(0<=this.matchingIndex?"("+this.matchingNode+")":"")+"]"+b+"("+this.x+","+this.y+","+this.z+")"});n(c$,"getFloatProperty",function(a){return"property_atomclass"===a?this.atomClass:NaN},"~S");n(c$,"getNominalMass",function(){return this.getAtomicMass()});n(c$,"getCIPChirality",function(){return""},"~B");n(c$,"setCIPChirality",function(){},"~N");H(c$,"UNBRACKETED_SET","B, C, N, O, P, S, F, Cl, Br, I, *,")});B("JS");C(["JU.Edge"],"JS.SmilesBond",["JS.InvalidSmilesException"],
-function(){c$=D(function(){this.atom2=this.atom1=null;this.isNot=!1;this.primitives=this.matchingBond=null;this.nPrimitives=0;this.bondsOr=null;this.nBondsOr=0;this.isConnection=!1;this.atropType=null;this.isChain=!1;E(this,arguments)},JS,"SmilesBond",JU.Edge);c$.getBondOrderString=j(c$,"getBondOrderString",function(a){switch(a){case 2:return"=";case 3:return"#";case 4:return"$";default:return""}},"~N");c$.getBondTypeFromCode=j(c$,"getBondTypeFromCode",function(a){switch(a){case ".":return 0;case "-":return 1;
-case "=":return 2;case "#":return 3;case "$":return 4;case ":":return 17;case "/":return 1025;case "\\":return 1041;case "^":return 65537;case "`":return 65538;case "@":return 65;case "~":return 81;case "+":return 96}return-1},"~S");j(c$,"set",function(a){this.order=a.order;this.isNot=a.isNot;this.primitives=a.primitives;this.nPrimitives=a.nPrimitives;this.bondsOr=a.bondsOr;this.nBondsOr=a.nBondsOr},"JS.SmilesBond");j(c$,"setAtropType",function(a){this.atropType=t(-1,[P(a/10)-1,a%10-1])},"~N");j(c$,
-"setPrimitive",function(a){a=this.primitives[a];this.order=a.order;this.isNot=a.isNot;this.atropType=a.atropType;return a},"~N");j(c$,"addBondOr",function(){null==this.bondsOr&&(this.bondsOr=Array(2));if(this.nBondsOr>=this.bondsOr.length){var a=Array(2*this.bondsOr.length);System.arraycopy(this.bondsOr,0,a,0,this.bondsOr.length);this.bondsOr=a}a=new JS.SmilesBond(null,null,-1,!1);this.bondsOr[this.nBondsOr]=a;this.nBondsOr++;return a});j(c$,"addPrimitive",function(){null==this.primitives&&(this.primitives=
-Array(2));if(this.nPrimitives>=this.primitives.length){var a=Array(2*this.primitives.length);System.arraycopy(this.primitives,0,a,0,this.primitives.length);this.primitives=a}a=new JS.SmilesBond(null,null,-1,!1);this.primitives[this.nPrimitives]=a;this.nPrimitives++;return a});n(c$,"toString",function(){return this.atom1+" -"+(this.isNot?"!":"")+this.order+"- "+this.atom2});F(c$,function(a,b,c,d){M(this,JS.SmilesBond,[]);this.set2(c,d);this.set2a(a,b)},"JS.SmilesAtom,JS.SmilesAtom,~N,~B");j(c$,"set2",
-function(a,b){this.order=a;this.isNot=b},"~N,~B");j(c$,"set2a",function(a,b){null!=a&&(this.atom1=a,a.addBond(this));null!=b&&(this.atom2=b,b.isBioAtomWild&&this.atom1.isBioAtomWild&&(this.order=96),b.isFirst=!1,b.addBond(this))},"JS.SmilesAtom,JS.SmilesAtom");j(c$,"setAtom2",function(a){this.atom2=a;null!=this.atom2&&(a.addBond(this),this.isConnection=!0)},"JS.SmilesAtom,JS.SmilesSearch");j(c$,"isFromPreviousTo",function(a){return!this.isConnection&&this.atom2===a},"JS.SmilesAtom");c$.isBondType=
+", ";return"["+a+"."+this.index+(0<=this.matchingIndex?"("+this.matchingNode+")":"")+"]"+b+"("+this.x+","+this.y+","+this.z+")"});n(c$,"getFloatProperty",function(a){return"property_atomclass"===a?this.atomClass:NaN},"~S");n(c$,"getNominalMass",function(){return this.getAtomicMass()});n(c$,"getCIPChirality",function(){return""},"~B");n(c$,"setCIPChirality",function(){},"~N");n(c$,"getXYZ",function(){return this});H(c$,"UNBRACKETED_SET","B, C, N, O, P, S, F, Cl, Br, I, *,")});B("JS");C(["JU.Edge"],
+"JS.SmilesBond",["JS.InvalidSmilesException"],function(){c$=D(function(){this.atom2=this.atom1=null;this.isNot=!1;this.primitives=this.matchingBond=null;this.nPrimitives=0;this.bondsOr=null;this.nBondsOr=0;this.isConnection=!1;this.atropType=null;this.isChain=!1;E(this,arguments)},JS,"SmilesBond",JU.Edge);c$.getBondOrderString=j(c$,"getBondOrderString",function(a){switch(a){case 2:return"=";case 3:return"#";case 4:return"$";default:return""}},"~N");c$.getBondTypeFromCode=j(c$,"getBondTypeFromCode",
+function(a){switch(a){case ".":return 0;case "-":return 1;case "=":return 2;case "#":return 3;case "$":return 4;case ":":return 17;case "/":return 1025;case "\\":return 1041;case "^":return 65537;case "`":return 65538;case "@":return 65;case "~":return 81;case "+":return 96}return-1},"~S");j(c$,"set",function(a){this.order=a.order;this.isNot=a.isNot;this.primitives=a.primitives;this.nPrimitives=a.nPrimitives;this.bondsOr=a.bondsOr;this.nBondsOr=a.nBondsOr},"JS.SmilesBond");j(c$,"setAtropType",function(a){this.atropType=
+t(-1,[P(a/10)-1,a%10-1])},"~N");j(c$,"setPrimitive",function(a){a=this.primitives[a];this.order=a.order;this.isNot=a.isNot;this.atropType=a.atropType;return a},"~N");j(c$,"addBondOr",function(){null==this.bondsOr&&(this.bondsOr=Array(2));if(this.nBondsOr>=this.bondsOr.length){var a=Array(2*this.bondsOr.length);System.arraycopy(this.bondsOr,0,a,0,this.bondsOr.length);this.bondsOr=a}a=new JS.SmilesBond(null,null,-1,!1);this.bondsOr[this.nBondsOr]=a;this.nBondsOr++;return a});j(c$,"addPrimitive",function(){null==
+this.primitives&&(this.primitives=Array(2));if(this.nPrimitives>=this.primitives.length){var a=Array(2*this.primitives.length);System.arraycopy(this.primitives,0,a,0,this.primitives.length);this.primitives=a}a=new JS.SmilesBond(null,null,-1,!1);this.primitives[this.nPrimitives]=a;this.nPrimitives++;return a});n(c$,"toString",function(){return this.atom1+" -"+(this.isNot?"!":"")+this.order+"- "+this.atom2});F(c$,function(a,b,c,d){M(this,JS.SmilesBond,[]);this.set2(c,d);this.set2a(a,b)},"JS.SmilesAtom,JS.SmilesAtom,~N,~B");
+j(c$,"set2",function(a,b){this.order=a;this.isNot=b},"~N,~B");j(c$,"set2a",function(a,b){null!=a&&(this.atom1=a,a.addBond(this));null!=b&&(this.atom2=b,b.isBioAtomWild&&this.atom1.isBioAtomWild&&(this.order=96),b.isFirst=!1,b.addBond(this))},"JS.SmilesAtom,JS.SmilesAtom");j(c$,"setAtom2",function(a){this.atom2=a;null!=this.atom2&&(a.addBond(this),this.isConnection=!0)},"JS.SmilesAtom,JS.SmilesSearch");j(c$,"isFromPreviousTo",function(a){return!this.isConnection&&this.atom2===a},"JS.SmilesAtom");c$.isBondType=
 j(c$,"isBondType",function(a,b,c){if(">"==a)return 1;if(0>"-=#$:/\\.~^`+!,&;@".indexOf(a))return 0;if(!b&&0>"-=#$:/\\.~^`".indexOf(a))throw new JS.InvalidSmilesException("SMARTS bond type "+a+" not allowed in SMILES");switch(a){case "~":return c?0:1;case "^":case "`":return-1;default:return 1}},"~S,~B,~B");j(c$,"getBondType",function(){return this.order});j(c$,"getValence",function(){return this.order&7});j(c$,"getOtherAtom",function(a){return this.atom1===a?this.atom2:this.atom1},"JS.SmilesAtom");
-n(c$,"getAtomIndex1",function(){return this.atom1.index});n(c$,"getAtomIndex2",function(){return this.atom2.index});n(c$,"getCovalentOrder",function(){return this.order});n(c$,"getOtherAtomNode",function(a){return a===this.atom1?this.atom2:a===this.atom2?this.atom1:null},"JU.Node");n(c$,"isCovalent",function(){return 112!=this.order});n(c$,"isHydrogen",function(){return 112==this.order});j(c$,"switchAtoms",function(){var a=this.atom1;this.atom1=this.atom2;this.atom2=a;switch(this.order){case 65537:this.order=
+n(c$,"getAtomIndex1",function(){return this.atom1.index});n(c$,"getAtomIndex2",function(){return this.atom2.index});n(c$,"getCovalentOrder",function(){return this.order});n(c$,"getOtherAtomNode",function(a){return a===this.atom1?this.atom2:a===this.atom2||null==a?this.atom1:null},"JU.Node");n(c$,"isCovalent",function(){return 112!=this.order});n(c$,"isHydrogen",function(){return 112==this.order});j(c$,"switchAtoms",function(){var a=this.atom1;this.atom1=this.atom2;this.atom2=a;switch(this.order){case 65537:this.order=
 65538;break;case 65538:this.order=65537;break;case 1025:this.order=1041;break;case 1041:this.order=1025}});H(c$,"TYPE_UNKNOWN",-1,"TYPE_NONE",0,"TYPE_AROMATIC",17,"TYPE_RING",65,"TYPE_ANY",81,"TYPE_BIO_SEQUENCE",96,"TYPE_BIO_CROSSLINK",112,"ALL_BONDS","-=#$:/\\.~^`+!,&;@","SMILES_BONDS","-=#$:/\\.~^`")});B("JS");C(null,"JS.SmilesMeasure",["JU.PT"],function(){c$=D(function(){this.search=null;this.index=this.type=this.nPoints=0;this.isNot=!1;this.points=this.minmax=this.indices=null;E(this,arguments)},
 JS,"SmilesMeasure");I(c$,function(){this.indices=t(4,0);this.points=Array(4)});F(c$,function(a,b,c,d,e){this.search=a;this.type=Math.min(4,Math.max(c,2));this.index=b;this.isNot=d;this.minmax=e;for(a=e.length-2;0<=a;a-=2)e[a]>e[a+1]&&(b=e[a+1],e[a+1]=e[a],e[a]=b)},"JS.SmilesSearch,~N,~N,~B,~A");j(c$,"addPoint",function(a){if(this.nPoints==this.type)return!1;if(0==this.nPoints)for(var b=1;b<this.type;b++)this.indices[b]=a+b;this.indices[this.nPoints++]=a;return!0},"~N");j(c$,"check",function(){for(var a=
 0;a<this.type;a++){var b=this.search.patternAtoms[this.indices[a]].getMatchingAtomIndex();this.points[a]=this.search.targetAtoms[b]}b=0;switch(this.type){case 2:b=this.points[0].distance(this.points[1]);break;case 3:this.search.v.vA.sub2(this.points[0],this.points[1]);this.search.v.vB.sub2(this.points[2],this.points[1]);b=this.search.v.vA.angle(this.search.v.vB)/0.017453292;break;case 4:b=JS.SmilesMeasure.setTorsionData(this.points[0],this.points[1],this.points[2],this.points[3],this.search.v,!0)}for(a=
